==> graveman_0.3.5.tar.gz: graveman-0.3.5/src/main.c <==
/* main.c
 * Copyright (C) 2004, 2005 Sylvain Cresto <sylvain.cresto@tiscali.fr>
 *
 * This file is part of graveman!
 *
 * graveman! is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or
 * (at your option) any later version.
 * 
 * graveman! is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with program; see the file COPYING. If not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
 * MA 02111-1307, USA. 
 * 
 * URL: http://www.nongnu.org/graveman/
 *
 */

#include "graveman.h"

GladeXML *Gxml = NULL;

gboolean graveman_init(gint Aargc, gchar *Aargv[]) {
  gint i;
  gchar *ptr;
  for (i = 1; i <= Aargc; i++) {
    ptr = Aargv[i-1];
    while (*ptr=='-') ptr++;
    if (*ptr == 'v') {
      g_printf("%s\n", VERSION);
      return FALSE;
    } else if (*ptr == 'V') {
      g_printf("%s: %s\n", _("Version"), VERSION);
      g_printf("%s: %s\n", _("Compiled with ogg vorbis support"), 
#ifdef ENABLE_OGG
          _("yes")
#else
          _("no")
#endif
          );
      g_printf("%s: %s\n", _("Compiled with mp3 support"), 
#ifdef ENABLE_MP3
          _("yes")
#else
          _("no")
#endif
          );
      g_printf("%s: %s\n", _("Compiled with linux-ide devices support"),
#ifdef LINUX_IDE
          _("yes")
#else
          _("no")
#endif
          );

      g_printf("%s %s\n", _("Compiled"), 
#ifdef DEBUG
          _("with debug support")
#else
          _("without debug support")
#endif
          );
      return FALSE;
    } else if (*ptr == 'h') {
      g_printf("%s %s\n", PACKAGE, VERSION); 
      g_printf(_("By Sylvain Cresto <sylvain.cresto@tiscali.fr>\n\n"));
      g_printf("  %s %s %s\n"
               "\t-v\t%s\n"
               "\t-V\t%s\n\n",
              _("Usage:"), Aargv[0], _("[options]"), _("show version number."),
               _("show compilation informations."));
      return FALSE;
    }

  }

  return TRUE;
}

gboolean graveman_glade_init(gchar *Afilename) {
  if (!Gxml) {
    if (!(Gxml = glade_xml_new(Afilename,NULL,NULL))) {
      g_warning("Error init glade !\n");
      return FALSE;
    }

    glade_xml_signal_autoconnect(Gxml);
  }
  return TRUE;
}

/* programme principal ! */
gint main (gint Aargc, gchar *Aargv[])
{
  GError *Lerror = NULL;
  GtkWidget *Lwindow1;
  guint32 Laudiolen = 0, Ldatasize = 0;
  guint32 Laudiomaxlen = 4800;  /* par defaut, cd audio de 80 minutes */
  guint32 Ldatamaxsize = 700 * 1024 * 1024; /* par defaut, cd de donnee de 700 Mb */

  if (!graveman_init(Aargc, Aargv)) return EXIT_SUCCESS;

#ifdef ENABLE_NLS
  bindtextdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR);
  bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
  textdomain (GETTEXT_PACKAGE);
#endif

  gtk_init (&Aargc, &Aargv);

  add_pixmap_directory (PACKAGE_DATA_DIR "/" PACKAGE );
//  graveman_glade_init(PACKAGE_DATA_DIR "/" PACKAGE "/" PACKAGE ".glade");

  /* on regarde si il y a un fichier de configuration present, si non on en
   * genere un nouveau */
  config_init();
  if (!is_config_valide()) {
    GHashTable *Lhash = _hash();
    manage_config(Lhash, SEARCH_LECTEUR + SEARCH_PROG + WRITE_CONFIG, &Lerror);
    g_free(Lhash);
    welcome_to_graveman();
  } else {
    read_config(&Lerror);
  }

  load_all_images();
  
  Lwindow1 = manage_main_window (&Laudiolen, &Laudiomaxlen, &Ldatasize, &Ldatamaxsize);  
  gtk_main ();
  /* on libere avant de quitter */
  if (Lerror) g_error_free(Lerror);
  if (GTK_IS_WIDGET(Lwindow1)) {
    gtk_widget_destroy(Lwindow1);
  }

  free_all_images();
  
  return EXIT_SUCCESS;
}

/*
 * vim:et:ts=8:sts=2:sw=2
 */

==> graveman_0.3.10-2.orig.tar.gz: graveman-0.3.10/src/main.c <==
/* main.c
 * Copyright (C) 2004, 2005 Sylvain Cresto <scresto@gmail.com>
 *
 * This file is part of graveman!
 *
 * graveman! is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or
 * (at your option) any later version.
 * 
 * graveman! is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with program; see the file COPYING. If not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
 * MA 02111-1307, USA. 
 * 
 * URL: http://www.nongnu.org/graveman/
 *
 */

#include "graveman.h"

GladeXML *Gxml = NULL;


gboolean graveman_glade_init(gchar *Afilename) {
  if (!Gxml) {
    if (!(Gxml = glade_xml_new(Afilename,NULL,NULL))) {
      g_warning("Error init glade !\n");
      return FALSE;
    }

    glade_xml_signal_autoconnect(Gxml);
  }
  return TRUE;
}

/* programme principal ! */
gint main (gint Aargc, gchar *Aargv[])
{
  GError *Lerror = NULL;
  guint64 Laudiolen = 0, Ldatasize = 0, Ldvdsize = 0;
  guint64 Laudiomaxlen = 4800;  /* par defaut, cd audio de 80 minutes */
  guint64 Ldatamaxsize = 700 * 1024 * 1024; /* par defaut, cd de donnee de 700 Mb */
  guint64 Ldvddatamaxsize = G_GINT64_CONSTANT(4700000000); /* pas default, dvd de donnee de 4.7 Gb */

#ifdef ENABLE_NLS
  bindtextdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR);
  bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
  textdomain (GETTEXT_PACKAGE);
#endif
  gtk_init (&Aargc, &Aargv);

  if (!graveman_init(Aargc, Aargv)) return EXIT_SUCCESS;

  add_pixmap_directory (PACKAGE_DATA_DIR "/" PACKAGE );

  /* on regarde si il y a un fichier de configuration present, si non on en
   * genere un nouveau */
  config_init();
  if (get_config_file(R_OK) == FALSE) {
    Tgrave *Lg = sc_grave_newempty();
    manage_config(Lg, SEARCH_LECTEUR + CONF_INIT_DEFAULT + SEARCH_PROG + SEARCH_CHARSETS + WRITE_CONFIG, &Lerror);
    sc_grave_destroy(Lg);
    welcome_to_graveman();
  } else {
    if (read_config(&Lerror)==FALSE) return EXIT_FAILURE;
    if (conf_get_boolean("scan_drives") || param_get_boolean("scan_drives"))
    {
      Tgrave *Lg = sc_grave_newempty();
      /* scan for new drives on startup */
      manage_config(Lg, SEARCH_LECTEUR, &Lerror);
      sc_grave_destroy(Lg);
    }
  }

  load_all_images();
  
  manage_main_window (&Laudiolen, &Laudiomaxlen, &Ldatasize, &Ldatamaxsize, &Ldvdsize, &Ldvddatamaxsize); 

  gtk_main ();

  /* on libere avant de quitter */
  if (Lerror) g_error_free(Lerror);

  free_all_images();
  
  return EXIT_SUCCESS;
}

/*
 * vim:et:ts=8:sts=2:sw=2
 */
